/*
  conffile.h
  Copyright (C) 2008 Tomohiro Masubuchi <bucchi@e-ml.jp>

  This file is part of wpa_setting.

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __CONFFILE_H__
#define __CONFFILE_H__

#include <qstring.h>
#include <qfile.h>

class ConfFile
{
  public:
	ConfFile(QString const &filename);
	~ConfFile();

	enum ProtoType {
		None_WEP,
		WPA,
#if 0
		WPA2,
		WPA2_WPA,
#endif
		MAX_PROTO
	};

	enum EncType {
		TKIP,
		AES,
		AES_TKIP,
		MAX_ENC
	};

	bool isWlan();

	QString getName();
	QString getSSID();
	ProtoType getProtocolType();
//	EncType getEncryptType();
	QString getProtocolName();
//	QString getEncryptName();
	QString getPassPhrase();
	bool getStealthSSID();

	bool setSSID(QString const &ssid);
	bool setProtocolType(ProtoType type);
	bool setEncryptType(EncType type);
	bool setPassPhraseASCII(QString const &ssid);
	bool setStealthSSID(bool value);

	bool commitChanges();

  protected:
	bool valid;
	QString wlanfilename;
	QString scheme;
	QString name;
	QString ssid;
	QString passphrase;
	bool proto_wpa;
	bool scan_ssid;

	QString convHexToBin(QString const &hex);
	QString convBinToHex(QString const &bin);

	QString escapeAndQuote(QString const &str);

	bool loadQPEconfig(QString const &file);
	bool loadWPAconfig(QString const &file);

	void saveWLANconfig();
	void saveQPEconfig();
	void saveWPAconfig();
};

#endif // __CONFFILE_H__
